#

##

##

##

##

##

    	objectives
    		# agenda
    		# navigation
    		# ambitions
    		# courses
    		# logistics
    		# governance
    		# strategies

    	urgent
    		# important

    	ranked

    		[ ] cache HTML, CSS, JS with semver

    			example: index-2.1.0-c71784a5.js

    		[ ] opacity around the edges of the (multi)story panels

    		[ ] localhost popup doesn't reappear after turned on again in climate panel

    		[ ] outbound link icon

    		[ ] food "measured ingredients" with unreported mass
    			that doesn't include mass equivalents.

    		[ ] search: has affiliate links

    		[ ] calculate grocery stats when the grocery list page is opened
    			and when quantities are modified on the grocery list page.

    		[ ] CMS "regions" and "parcels" text

    		[ ] search: filter by "supplements" or "food"
    		[ ] search: sort reverse alphabetical
    		[ ] search: filter by "goodness certification"

    				VEGECERT CERTIFIED VEGAN

    				BEVEG CERTIFIED

    				VEGAN®

    				CERTIFIED PLANT BASED

    				CERTIFIED VEGAN VEGAN.ORG

    		[ ] USDA source "api" to "API"

    		[ ] [foods] measured ingredients section

    		[ ] human breast milk composition (if you're a human)

    		[ ] if you're a cow:
    			[ ] cow milk composition

    		[ ] https://www.faire.com

    	unranked
    		[ ] contact page to MongoDB

    		[ ] [scan] The "after" count on the first paper is wrong.

    		[ ] [cart] rerun the stats on the cart page if the amounts change

    		[ ] [scan]	"previous" on scan goes back to the beginning,
    					where as it should go

    		[ ] if zero, then remove from cart

    		[ ] [scan] show top nutrients of treasures
    		[ ] [scan] show energy per gram of treasures
    		[ ] [scan] filter
    			[ ] foods
    			[ ] supplements

    		[ ] [scan] filter: { structure } fraction of essential nutrients
    			[ ] protein >= 20%
    			[ ] [vitamin A] [in foods] >= 10%

    		[ ] [scan] filters
    			[ ] kind === supplement
    				[ ] supplement kind === TABLETS
    				[ ] supplement kind === POWDER
    				[ ] supplement kind === TABLETS or PILLS or CAPSULES

    		[ ] pie chart of nutrients for foods that
    			have the package amount known.

    	possibilities
    		[ ] a foundation food like:
    			[ ]	soybeans with advanced audio visual inkscape or d3 visual!

    		[ ] [USDA food] ingredient parsing
    		[ ] [USDA food] unreported ingredients amount

    		[ ] [NIH supps] ingredient parsing

    		[ ] [scan] on keyup in scan box (with rhythm filter) -> "## finds"

    		? [ ] https://github.com/riccardoscalco/textures
    				hex texture?

    		[ ] systemctl flask

    		[ ] recipes:

    			[ ] amount:

    				[ ] ounces
    				[ ] grams
    				[ ] packages

    		[ ] process level alerts variable

    				goodest_physics.py {
    					"alert level": "emergency"
    				}

    				levels:
    					"emergency"
    					"caution"
    					"info"
    					"scholar"

    				summary:
    					"emergency" is [ "emergency" ]

    					"caution" is [ "emergency", "caution" ]

    					"info" is [ "emergency", "caution", "info" ]

    					"scholar" is [ "emergency", "caution", "info", "scholar" ]

    		[ ] hatch as build system

    		[ ] lint

    		[ ] how to obtain?

    				pip install goodest

    				/goodest_adventure
    					/modules_pip
    						/goodest

    					essence.py

    					[sh] goodest adventures on
    					[sh] goodest adventures monetary saves import --name 3.JSON

    		[ ]
    			goodest ["retrieve food"] ()
    			[GET] /retrieve_food
    			[WS] "retrieve food"

    		[ ] mongo instead of tinydb

    			[ ] save & rebuild, export & dump

    			[ ] two URLs
    				( ) mongo besties URL
    				( ) local URL

    		[ ] essence
    			( ) from path
    			( ) configurable in memory

    			[ ] search "essence.py" in CWD by preset

    		[ ] food treasure:nature from mongo ingredients

    		[ ] supp treasure:nature from mongo ingredients

    		itinerary, ranked:
    			[ ] fractional amounts of essentials

    			[ ] supp, fractional amounts of measured ingredients

    			maybe:
    				[ ] food, fractional amounts of measured ingredients

    			[ ] besties/food_USDA/nature_v2/_status/status_2_form.py

    					change serving size unit to "grams" from "g"?

    		possibilities

    			[ ] 100% organic eco-friendly from sustainable farming.

    			instances:
    				programmatic:
    					import goodest
    					goodest_1 = goodest.instantiate ()

    				click:
    					[xonsh] goodest instantiate